package com.jkcredit.asynchronous.callback.service.impl;

import cn.hutool.core.lang.UUID;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.jkcredit.asynchronous.callback.constants.BookingSpaceConstant;
import com.jkcredit.asynchronous.callback.model.BookingSpaceResponseObject;
import com.jkcredit.asynchronous.callback.service.BookingSpaceService;
import com.jkcredit.asynchronous.callback.util.OkHttpUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.io.*;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Service
@Slf4j
@RequiredArgsConstructor
public class BookingSpaceServiceImpl implements BookingSpaceService {
    @Value("${userInfoPath}")
    private String userInfoPath;

    private final StringRedisTemplate stringRedisTemplate;

    @Override
    public BookingSpaceResponseObject reply(String replyParam) {
        String uuid = UUID.randomUUID().toString();
        stringRedisTemplate.boundHashOps(BookingSpaceConstant.REDIS_KEY_SEND).put(BookingSpaceConstant.REPLY + "_" + uuid, replyParam);
        return BookingSpaceResponseObject.success();
    }

    @Override
    public BookingSpaceResponseObject confirm(String confirmParam) {
        String uuid = UUID.randomUUID().toString();
        stringRedisTemplate.boundHashOps(BookingSpaceConstant.REDIS_KEY_SEND).put(BookingSpaceConstant.CONFIRM + "_" + uuid, confirmParam);
        return BookingSpaceResponseObject.success();
    }

    @Override
    public boolean callBack(String methodType, String requestParam) {
        String userJson = getUserFromJsonFile();
        String requestUrl;
        boolean result = false;
        if (StringUtils.isNotBlank(userJson)) {
            JSONArray userArray = JSON.parseArray(userJson);
            JSONObject jsonObject = userArray.getJSONObject(0);
            if (methodType.equals(BookingSpaceConstant.REPLY)) {
                requestUrl = jsonObject.getString("replyUrl");
            } else {
                requestUrl = jsonObject.getString("confirmUrl");
            }

            String responseContext = OkHttpUtil.sendPost(requestUrl, requestParam, BookingSpaceConstant.OUT_TIME);
            if (StringUtils.isNotBlank(responseContext)) {
                result = true;
            }
        }
        return result;
    }

    private String getUserFromJsonFile() {
        String jsonStr = "";
        File jsonFile = new File(userInfoPath);
        try {
            FileReader fileReader = new FileReader(jsonFile);
            Reader reader = new InputStreamReader(new FileInputStream(jsonFile), "utf-8");
            int ch = 0;
            StringBuffer sb = new StringBuffer();
            while ((ch = reader.read()) != -1) {
                sb.append((char) ch);
            }
            fileReader.close();
            reader.close();
            jsonStr = sb.toString();
            return jsonStr;

        } catch (IOException ioe) {
            log.error("getUserFromJsonFile.IOException:", ioe);
            return jsonStr;
        }
    }
}
