package com.jkcredit.asynchronous.callback.task;

import cn.hutool.core.lang.UUID;
import com.jkcredit.asynchronous.callback.constants.BookingSpaceConstant;
import com.jkcredit.asynchronous.callback.service.BookingSpaceService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Component
@RequiredArgsConstructor
@Slf4j
public class BookingSpaceTask {
    private final BookingSpaceService bookingSpaceService;
    private final StringRedisTemplate stringRedisTemplate;

    @Scheduled(cron = "0 0/5 * * * ?", zone = "Asia/Shanghai")
    public void callBackTask() {
        Map<Object, Object> paramMap = stringRedisTemplate.boundHashOps(BookingSpaceConstant.REDIS_KEY_SEND).entries();
        for (Map.Entry<Object, Object> entry : paramMap.entrySet()) {
            String key = entry.getKey().toString();
            String[] keyArray = key.split("_");
            stringRedisTemplate.boundHashOps(BookingSpaceConstant.REDIS_KEY_SEND).delete(key);
            boolean callBackResult = bookingSpaceService.callBack(keyArray[0], entry.getValue().toString());
            log.info("推送类型:{}, 推送消息:{}, 推送结果:{}", keyArray[0], entry.getValue(), callBackResult);
            if (!callBackResult) {
                stringRedisTemplate.boundHashOps(BookingSpaceConstant.REDIS_KEY_SEND).put(key, entry.getValue());
            }
        }
    }
}
